<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
<context>
    <name>ExpressionBar</name>
    <message>
        <source>Expression Error</source>
        <translation>表达式错误</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Dark Theme</source>
        <translation>深色主题</translation>
    </message>
    <message>
        <source>Simple mode</source>
        <translation>简单模式</translation>
    </message>
    <message>
        <source>Scientific mode</source>
        <translation>科学模式</translation>
    </message>
    <message>
        <source>Deepin Calculator</source>
        <translation>深度计算器</translation>
    </message>
    <message>
        <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
        <translation>深度计算器是一款简单易用的桌面计算器，支持加、减、乘、除功能。</translation>
    </message>
</context>
<context>
    <name>SimpleListDelegate</name>
    <message>
        <source>Expression Error</source>
        <translation>表达式错误</translation>
    </message>
</context>
</TS>